@@ -1,7 +1,7 @@
 # -------------------------------------------------------------------------
 make_palette <- function(x, quiet = FALSE, suggest = NULL) {
   function(n) {
-    if (!is.numeric(n)) stop("n is not a number")
+    if (!is.numeric(n)) abort("n is not a number")
 
     if (n <= length(x)) {
       x[seq_len(n)]
@@ -64,8 +64,6 @@ muted_colors <- c(
 #'
 #' @aliases palettes vibrant muted
 #'
-#' @importFrom grDevices colorRampPalette
-#'
 #' @examples
 #' vibrant(5)
 #' muted(10)
